=============================
Sudokumizer
=============================

.. image:: https://badge.fury.io/py/sudokumizer.png
    :target: http://badge.fury.io/py/sudokumizer

.. image:: https://travis-ci.org/tomasforsman/sudokumizer.png?branch=master
    :target: https://travis-ci.org/tomasforsman/sudokumizer

The board() method returns a Sudoku board sollution. Use as a starting point for your own Sudoku creations.


Features
--------

* TODO

